@@ -628,9 +628,10 @@ private: // no copy
 struct TreeBranch {
     double t;
     double value;
+    double T;
     TreeBranch *b[2];// 2 pointeur on 2 branch if existe
     int id;// id[1] == 0 => just a branch //
-    TreeBranch() : t(0), value(0), b{0, 0}, id{-1} {}
+    TreeBranch() : t(0), value(0), T(0), b{0, 0}, id{-1} {}
 
     bool internal() const {
         assert((b[0] == 0 && b[1] == 0) == (id != -1));
@@ -771,7 +772,8 @@ Forest::Forest(string fn)
 
         if (p) {
             f.push_back(p);
-            T = max(T, SetTime(p, 0, nt, ni));
+            p->T = SetTime(p, 0, nt, ni);
+            T = max(T, p->T);
             if (p->value) {
                 // have not yet read the ;
                 if (ff.get() != ';') {
@@ -860,6 +862,13 @@ void SetDataOde(Forest &f, vector<DataOde> &vdo, R T) {
     //  if(debug) cout << " size of vdo: "<< vdo.size() << endl;
 }
 
+void SetDataOde(Forest &f, vector<DataOde> &vdo) {
+    for (int i = 0; i < f.size(); ++i) {
+        SetDataOde(f[i], f[i]->T, vdo, 0);
+    }
+    //  if(debug) cout << " size of vdo: "<< vdo.size() << endl;
+}
+
 int oneeee = 0;
 
 double duratinit = 0, duratopt = 0, duratbuild = 0, duraterr = 0;
@@ -1441,10 +1450,18 @@ Solution
 
 
     Forest forest(treename);
-    if (T < forest.T) T = forest.T;
     vector<DataOde> vdo;
     vector<tuple<double, int, int >> vs;
-    SetDataOde(forest, vdo, T);
+
+    // If T is given, assume it is the same for all trees, otherwise keep tree-specific Ts (from root till last tree's tip)
+    if (T <= 0) {
+        cout << "Using tree-specific sampling periods (between tree start and tree's last sampled tip)." << endl;
+        SetDataOde(forest, vdo);
+    } else {
+        T = max(T, forest.T);
+        cout << "Using global time " << T << " for the sampling period." << endl;
+        SetDataOde(forest, vdo, T);
+    }
 
     for (int i = 0; i < vdo.size(); ++i) {
         DataOde &vdoi = vdo[i];
@@ -1636,8 +1653,14 @@ R calculateLikelihood(const string &treename, R mu, R lambda, R psi, R p, R pie,
 
     Forest forest(treename);
     vector<DataOde> vdo;
-    if (T < forest.T) T = forest.T;
-    SetDataOde(forest, vdo, T);
+    if (T <= 0) {
+        cout << "Using tree-specific sampling periods (between tree start and tree's last sampled tip)." << endl;
+        SetDataOde(forest, vdo);
+    } else {
+        T = max(T, forest.T);
+        cout << "Using global time " << T << " for the sampling period." << endl;
+        SetDataOde(forest, vdo, T);
+    }
 
     return -JCout(&predefdata[0], pie, u, vdo, eps);
 }
