@@ -177,8 +177,7 @@ def infer(nwk, start=None, upper_bounds=None, pi_E=-1,
 
     def get_res(_nwk):
         return _pybdei.infer(f=_nwk, start=starts, ub=upper_bounds, pie=pi_E,
-                                 mu=mu, la=la, psi=psi, p=p, T=T, u=u,
-                                 nt=threads, nbiter=CI_repetitions, nstarts=nstarts)
+                             mu=mu, la=la, psi=psi, p=p, T=T, u=u, nt=threads, nbiter=CI_repetitions, nstarts=nstarts)
 
     try:
         res = get_res(nwk)
